--[[

ReagentCalc
	by Mattperry (http://somewhere.fscked.org)
	copyright: GNU General Public License (http://www.gnu.org/copyleft/gpl.html)

Allows you to find out in advance how many reagents it will cost you in order
to create a set of trade skill items.  This is useful for those profession
quests where you need to create several different items, and you want to know
what reagents it will require to make them all.

Usage:
  Type /rc or /reagentcalc to open the ReagentCalc window.
  Open a Trade Skill window (such as Blacksmithing, or First Aid).
  Select an item in the Trade Skill window, and set the count to whatever number you wish.
  Click "Add" in the ReagentCalc window to add that many items to the "todo" list.
  ReagentCalc will show you how many reagents are required to create all the items you've added.
  Closing the ReagentCalc window does not erase the list of items, so you can go about your business and come back to it later.
  Click "Clear" to clear the list of items.

Note: currently, the reagent list is not saved when you log out.

Version history:
v1: 2005mar28
	initial release

--]]

local P = {};
ReagentCalc = P;

P.skills = {};
P.reagents = {};

-- Internal functions

function P.OnLoad()
	SLASH_REAGENTCALC1 = "/reagentcalc";
	SLASH_REAGENTCALC2 = "/rc";
	SlashCmdList["REAGENTCALC"] = function(msg)
		P.Command(msg);
	end
end

function P.Command(msg)
	P.UpdateInfo();
end

function P.Add(repeatCount)
	local id = GetTradeSkillSelectionIndex();

	if (id == 0 or repeatCount == 0) then
		UIErrorsFrame:AddMessage("You need to select something in the Trade Skill window.", 1.0, 0.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
		return;
	end

	-- record skill info
	local name = P.GetTradeItemName(id);
	if P.skills[name] == nil then P.skills[name] = {count = 0}; end
	P.skills[name].count = P.skills[name].count + repeatCount;

	-- record reagent info
	local numReagents = GetTradeSkillNumReagents(id);
	for i=1,numReagents do
		local name, texture, count, playerCount = GetTradeSkillReagentInfo(id, i);
		if P.reagents[name] == nil then P.reagents[name] = {count = 0}; end
		P.reagents[name].count = P.reagents[name].count + count*repeatCount;
		P.reagents[name].playerCount = playerCount;
	end

	P.UpdateInfo();
end

function P.Clear()
	P.skills = {};
	P.reagents = {};

	P.UpdateInfo();
end

function P.UpdateInfo()
	local text = "";

	text = text .. "In order to create:\n";
	for name, info in pairs(P.skills) do
		text = text .. "  " .. info.count .. " [" .. name .. "]\n";
	end

	text = text .. "\nYou will need:\n";
	for name, info in pairs(P.reagents) do
		text = text .. "  " .. info.count .. " [" .. name .. "]  (have " .. info.playerCount .. ", need " .. (info.count - info.playerCount) .. " more)\n";
	end
	ReagentCalcInfoText:SetText(text);
	ReagentCalcFrame:Show();
end

function P.GetTradeItemName(index)
	local linktext = GetTradeSkillItemLink(index);
	if (linktext) then
		local _,_,item = string.find(linktext, "^.*%[(.*)%].*$");
		return item;
	else
		local item, difficulty, amount = GetTradeSkillInfo(index);
		return item;
	end
end
